Class: AgUiProtocol::Core::Capabilities::IdentityCapabilities
- Inherits:
-
Types::Model
- Object
- Types::Model
- AgUiProtocol::Core::Capabilities::IdentityCapabilities
- Defined in:
- lib/ag_ui_protocol/core/capabilities.rb
Overview
Basic metadata about the agent.
Useful for discovery UIs, agent marketplaces, and debugging. Set these when you want clients to display agent information or when multiple agents are available and users need to pick one.
Instance Attribute Summary collapse
-
#description ⇒ Object
readonly
Returns the value of attribute description.
-
#documentation_url ⇒ Object
readonly
Returns the value of attribute documentation_url.
-
#metadata ⇒ Object
readonly
Returns the value of attribute metadata.
-
#name ⇒ Object
readonly
Returns the value of attribute name.
-
#provider ⇒ Object
readonly
Returns the value of attribute provider.
-
#type ⇒ Object
readonly
Returns the value of attribute type.
-
#version ⇒ Object
readonly
Returns the value of attribute version.
Instance Method Summary collapse
-
#initialize(name: nil, type: nil, description: nil, version: nil, provider: nil, documentation_url: nil, metadata: nil) ⇒ IdentityCapabilities
constructor
A new instance of IdentityCapabilities.
- #to_h ⇒ Object
Methods inherited from Types::Model
Constructor Details
#initialize(name: nil, type: nil, description: nil, version: nil, provider: nil, documentation_url: nil, metadata: nil) ⇒ IdentityCapabilities
Returns a new instance of IdentityCapabilities.
92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 92 def initialize( name: nil, type: nil, description: nil, version: nil, provider: nil, documentation_url: nil, metadata: nil ) @name = name @type = type @description = description @version = version @provider = provider @documentation_url = documentation_url @metadata = end |
Instance Attribute Details
#description ⇒ Object (readonly)
Returns the value of attribute description.
60 61 62 |
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 60 def description @description end |
#documentation_url ⇒ Object (readonly)
Returns the value of attribute documentation_url.
69 70 71 |
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 69 def documentation_url @documentation_url end |
#metadata ⇒ Object (readonly)
Returns the value of attribute metadata.
72 73 74 |
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 72 def @metadata end |
#name ⇒ Object (readonly)
Returns the value of attribute name.
54 55 56 |
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 54 def name @name end |
#provider ⇒ Object (readonly)
Returns the value of attribute provider.
66 67 68 |
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 66 def provider @provider end |
#type ⇒ Object (readonly)
Returns the value of attribute type.
57 58 59 |
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 57 def type @type end |
#version ⇒ Object (readonly)
Returns the value of attribute version.
63 64 65 |
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 63 def version @version end |
Instance Method Details
#to_h ⇒ Object
106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 106 def to_h { name: @name, type: @type, description: @description, version: @version, provider: @provider, documentation_url: @documentation_url, # `metadata` is arbitrary integration-specific identity info — preserve keys verbatim. metadata: @metadata.nil? ? nil : AgUiProtocol::Util::Opaque.new(@metadata) } end |