Class: AgUiProtocol::Core::Capabilities::StateCapabilities

Inherits:
Types::Model
  • Object
show all
Defined in:
lib/ag_ui_protocol/core/capabilities.rb

Overview

State and memory management capabilities.

These tell the client how the agent handles shared state and whether conversation context persists across runs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Types::Model

#as_json, #to_json

Constructor Details

#initialize(snapshots: nil, deltas: nil, memory: nil, persistent_state: nil) ⇒ StateCapabilities

Returns a new instance of StateCapabilities.



289
290
291
292
293
294
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 289

def initialize(snapshots: nil, deltas: nil, memory: nil, persistent_state: nil)
  @snapshots = snapshots
  @deltas = deltas
  @memory = memory
  @persistent_state = persistent_state
end

Instance Attribute Details

#deltasObject (readonly)

Returns the value of attribute deltas.



269
270
271
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 269

def deltas
  @deltas
end

#memoryObject (readonly)

Returns the value of attribute memory.



272
273
274
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 272

def memory
  @memory
end

#persistent_stateObject (readonly)

Returns the value of attribute persistent_state.



275
276
277
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 275

def persistent_state
  @persistent_state
end

#snapshotsObject (readonly)

Returns the value of attribute snapshots.



266
267
268
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 266

def snapshots
  @snapshots
end

Instance Method Details

#to_hObject



297
298
299
300
301
302
303
304
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 297

def to_h
  {
    snapshots: @snapshots,
    deltas: @deltas,
    memory: @memory,
    persistent_state: @persistent_state
  }
end