Module: AgUiProtocol::Core::Events
- Defined in:
- lib/ag_ui_protocol/core/events.rb
Overview
The Agent User Interaction Protocol Ruby SDK uses a streaming event-based architecture. Events are the fundamental units of communication between agents and the frontend. This section documents the event types and their properties.
## Lifecycle Events
These events represent the lifecycle of an agent run.
## Text Message Events
These events represent the lifecycle of text messages in a conversation.
## Tool Call Events
These events represent the lifecycle of tool calls made by agents.
## Thinking Events
These events represent the lifecycle of an agent’s thinking steps, conveying intermediate reasoning to the frontend without contributing to the final message.
## Reasoning Events
These events convey structured reasoning blocks emitted by an agent, including streaming reasoning messages and encrypted reasoning values.
## State Management Events
These events are used to manage agent state.
Defined Under Namespace
Modules: EventType Classes: ActivityDeltaEvent, ActivitySnapshotEvent, BaseEvent, CustomEvent, MessagesSnapshotEvent, RawEvent, ReasoningEncryptedValueEvent, ReasoningEndEvent, ReasoningMessageChunkEvent, ReasoningMessageContentEvent, ReasoningMessageEndEvent, ReasoningMessageStartEvent, ReasoningStartEvent, RunErrorEvent, RunFinishedEvent, RunFinishedInterruptOutcome, RunFinishedSuccessOutcome, RunStartedEvent, StateDeltaEvent, StateSnapshotEvent, StepFinishedEvent, StepStartedEvent, TextMessageChunkEvent, TextMessageContentEvent, TextMessageEndEvent, TextMessageStartEvent, ThinkingEndEvent, ThinkingStartEvent, ThinkingTextMessageContentEvent, ThinkingTextMessageEndEvent, ThinkingTextMessageStartEvent, ToolCallArgsEvent, ToolCallChunkEvent, ToolCallEndEvent, ToolCallResultEvent, ToolCallStartEvent
Constant Summary collapse
- TEXT_MESSAGE_ROLE_VALUES =
Valid values for the role attribute of a text message.
["developer", "system", "assistant", "user", "reasoning"].freeze