Class: AgUiProtocol::Core::Capabilities::HumanInTheLoopCapabilities
- Inherits:
-
Types::Model
- Object
- Types::Model
- AgUiProtocol::Core::Capabilities::HumanInTheLoopCapabilities
- Defined in:
- lib/ag_ui_protocol/core/capabilities.rb
Overview
Human-in-the-loop interaction support.
Enable these when your agent can pause execution to request human input, approval, or feedback before continuing.
Instance Attribute Summary collapse
-
#approvals ⇒ Object
readonly
Returns the value of attribute approvals.
-
#approve_with_edits ⇒ Object
readonly
Returns the value of attribute approve_with_edits.
-
#feedback ⇒ Object
readonly
Returns the value of attribute feedback.
-
#interrupts ⇒ Object
readonly
Returns the value of attribute interrupts.
-
#interventions ⇒ Object
readonly
Returns the value of attribute interventions.
-
#supported ⇒ Object
readonly
Returns the value of attribute supported.
Instance Method Summary collapse
-
#initialize(supported: nil, approvals: nil, interventions: nil, feedback: nil, interrupts: nil, approve_with_edits: nil) ⇒ HumanInTheLoopCapabilities
constructor
A new instance of HumanInTheLoopCapabilities.
- #to_h ⇒ Object
Methods inherited from Types::Model
Constructor Details
#initialize(supported: nil, approvals: nil, interventions: nil, feedback: nil, interrupts: nil, approve_with_edits: nil) ⇒ HumanInTheLoopCapabilities
Returns a new instance of HumanInTheLoopCapabilities.
602 603 604 605 606 607 608 609 610 611 612 |
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 602 def initialize( supported: nil, approvals: nil, interventions: nil, feedback: nil, interrupts: nil, approve_with_edits: nil ) @supported = supported @approvals = approvals @interventions = interventions @feedback = feedback @interrupts = interrupts @approve_with_edits = approve_with_edits end |
Instance Attribute Details
#approvals ⇒ Object (readonly)
Returns the value of attribute approvals.
572 573 574 |
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 572 def approvals @approvals end |
#approve_with_edits ⇒ Object (readonly)
Returns the value of attribute approve_with_edits.
584 585 586 |
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 584 def approve_with_edits @approve_with_edits end |
#feedback ⇒ Object (readonly)
Returns the value of attribute feedback.
578 579 580 |
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 578 def feedback @feedback end |
#interrupts ⇒ Object (readonly)
Returns the value of attribute interrupts.
581 582 583 |
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 581 def interrupts @interrupts end |
#interventions ⇒ Object (readonly)
Returns the value of attribute interventions.
575 576 577 |
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 575 def interventions @interventions end |
#supported ⇒ Object (readonly)
Returns the value of attribute supported.
569 570 571 |
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 569 def supported @supported end |
Instance Method Details
#to_h ⇒ Object
615 616 617 618 619 620 621 622 623 624 |
# File 'lib/ag_ui_protocol/core/capabilities.rb', line 615 def to_h { supported: @supported, approvals: @approvals, interventions: @interventions, feedback: @feedback, interrupts: @interrupts, approve_with_edits: @approve_with_edits } end |