Module: AgUiProtocol::Core::Events

Defined in:
lib/ag_ui_protocol/core/events.rb

Overview

The Agent User Interaction Protocol Ruby SDK uses a streaming event-based architecture. Events are the fundamental units of communication between agents and the frontend. This section documents the event types and their properties.

## Lifecycle Events

These events represent the lifecycle of an agent run.

## Text Message Events

These events represent the lifecycle of text messages in a conversation.

## Tool Call Events

These events represent the lifecycle of tool calls made by agents.

## State Management Events

These events are used to manage agent state.

Defined Under Namespace

Modules: EventType Classes: ActivityDeltaEvent, ActivitySnapshotEvent, BaseEvent, CustomEvent, MessagesSnapshotEvent, RawEvent, RunErrorEvent, RunFinishedEvent, RunStartedEvent, StateDeltaEvent, StateSnapshotEvent, StepFinishedEvent, StepStartedEvent, TextMessageChunkEvent, TextMessageContentEvent, TextMessageEndEvent, TextMessageStartEvent, ThinkingEndEvent, ThinkingStartEvent, ThinkingTextMessageContentEvent, ThinkingTextMessageEndEvent, ThinkingTextMessageStartEvent, ToolCallArgsEvent, ToolCallChunkEvent, ToolCallEndEvent, ToolCallResultEvent, ToolCallStartEvent

Constant Summary collapse

TEXT_MESSAGE_ROLE_VALUES =

Valid values for the role attribute of a text message.

["developer", "system", "assistant", "user"].freeze