Module: AgUiProtocol::Encoder

Defined in:
lib/ag_ui_protocol/encoder/event_encoder.rb

Overview

The Agent User Interaction Protocol uses a streaming approach to send events from agents to clients. The ‘EventEncoder` class provides the functionality to encode events into a format that can be sent over HTTP.

Defined Under Namespace

Classes: EventEncoder

Constant Summary collapse

AGUI_MEDIA_TYPE =

Media type for AGUI events

"application/vnd.ag-ui.event+proto"